import pandas as pd
from sklearn import svm
from sklearn.metrics import accuracy_score, precision_score, recall_score
from iapa.preML import split
import os

class Classification:
    def __init__(self, df, k, data_path):
        self.split_data = split(df)
        self.k = k
        self.data_path = data_path
        self.X_train = self.split_data[0]
        self.X_test = self.split_data[1]
        self.y_train = self.split_data[2]
        self.y_test = self.split_data[3]
        self.clf = svm.SVC(kernel = k)
    
    def execute(self): #Fit, predict and assess
        self.clf.fit(self.X_train, self.y_train.values.ravel())

        y_preds = self.clf.predict(self.X_test)

        results = {'Accuracy':0, 'Precision':0, 'Recall':0}
        results['Accuracy'] = round(accuracy_score(self.y_test, y_preds),5)
        results['Precision'] = round(precision_score(self.y_test, y_preds),5)
        results['Recall'] = round(recall_score(self.y_test, y_preds),5)
        
        pd.DataFrame(data=results, index=[0]).to_csv(os.path.join(self.data_path, "classification_metrics.csv"))
        print("Saved to " + self.data_path)
    
    
    def predict(self, X):
        preds = self.clf.predict(X)
        temp = pd.concat([X.reset_index(), pd.DataFrame(preds)], axis=1)
        temp.to_csv(os.path.join(self.data_path, "classification_predictions.csv"))
    


import pandas as pd
from sklearn.model_selection import train_test_split


def read(csv):
    return pd.read_csv(csv)

def split(df):
    X = df.iloc[:,:-1]
    y = df.iloc[:,-1:]
    X_train, X_test, y_train, y_test = train_test_split(X, y, test_size = 0.2, random_state = 42, stratify = y)
    return [X_train, X_test, y_train, y_test]





from iapa.preML import read
from iapa.classification import Classification
import os
import argparse

cwd = os.getcwd()

parser = argparse.ArgumentParser()
parser.add_argument("path")
args = parser.parse_args()
csv = args.path
print("Current Working Directory is at : " + cwd)
data_path = cwd
df = read(csv)
clf = Classification(df, "poly", data_path)
clf.execute()


from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 2 - Pre-Alpha',
    'Intended Audience :: Developers',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.8'
]

setup(
    name='iapa',
    packages=['iapa'],
    version='0.4',
    description='Predictive Analytics Library',
    long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
    url='',
    author='Sng Hao Jun',
    author_email='snghaojun@outlook.sg',
    license='MIT',
    classifiers=classifiers,
    keywords='predict',
    install_requires=['numpy','scikit-learn','pandas']
)